@@ -1,3 +1,5 @@
+-- NOTE RETURNING below requires SQLite 3.35
+
 -- name: now$
 SELECT CURRENT_TIMESTAMP;
 
@@ -10,8 +12,8 @@ SELECT sid, sname FROM Stuff WHERE sname LIKE :pattern ORDER BY 1;
 -- name: get_stuff_sid^
 SELECT sname FROM Stuff WHERE sid = :sid;
 
--- name: add_stuff!
-INSERT INTO Stuff(sname) VALUES (:sname);
+-- name: add_stuff$
+INSERT INTO Stuff(sname) VALUES (:sname) RETURNING sid;
 
 -- name: del_stuff_sid!
 DELETE FROM Stuff WHERE sid = :sid;
@@ -20,16 +22,16 @@ DELETE FROM Stuff WHERE sid = :sid;
 UPDATE Stuff SET sname = :sname WHERE sid = :sid;
 
 -- name: get_user_data^
-SELECT login, email, upass, admin FROM Auth WHERE :login IN (login, email);
+SELECT login, email, upass, admin
+FROM Auth WHERE :login IN (login, email);
 
 -- name: get_user_all
 SELECT login, email, upass, admin FROM Auth ORDER BY 1;
 
--- name: add_user!
-INSERT INTO Auth(login, email, upass, admin) VALUES (:login, :email, :upass, :admin);
-
--- name: add_user_login!
-INSERT INTO Auth(login, email, upass) VALUES (:login, :email, :upass);
+-- name: add_user$
+INSERT INTO Auth(login, email, upass, admin)
+  VALUES (:login, :email, :upass, :admin)
+  RETURNING aid;
 
 -- name: del_user_login!
 DELETE FROM Auth WHERE :login IN (login, email);
